% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Season.R
\name{Season}
\alias{Season}
\title{Compute seasonal mean}
\usage{
Season(data, time_dim = "sdate", monini, moninf, monsup, method = mean,
  na.rm = TRUE, ncores = NULL)
}
\arguments{
\item{data}{A named numeric array with at least one dimension 'time_dim'.}

\item{time_dim}{A character string indicating the name of dimension along
which the seasonal means are computed. The default value is 'sdate'.}

\item{monini}{An integer indicating what the first month of the time series is. 
It can be from 1 to 12.}

\item{moninf}{An integer indicating the starting month of the seasonal mean. 
It can be from 1 to 12.}

\item{monsup}{An integer indicating the end month of the seasonal mean. It 
can be from 1 to 12.}

\item{method}{An R function to be applied for seasonal calculation. For
example, 'sum' can be used for total precipitation. The default value is mean.}

\item{na.rm}{A logical value indicating whether to remove NA values along 
'time_dim' when calculating climatology (TRUE) or return NA if there is NA 
along 'time_dim' (FALSE). The default value is TRUE.}

\item{ncores}{An integer indicating the number of cores to use for parallel 
computation. The default value is NULL.}
}
\value{
An array with the same dimensions as data except along the 'time_dim' 
 dimension, of which the length changes to the number of seasons.
}
\description{
Compute the seasonal mean (or other methods) on monthly time series along
one dimension of a named multi-dimensional arrays. Partial season is not 
accounted.
}
\examples{
dat <- 1 : (12 * 5 * 2 * 3 * 2)
dim(dat) <- c(dat = 1, memb = 3, time = 12 * 5, lon = 2, lat = 2) 
res <- Season(data = dat, monini = 1, moninf = 1, monsup = 2)
dat <- 1 : (12 * 2 * 3)
dim(dat) <- c(dat = 2, time = 12, memb = 3)
res <- Season(data = dat, monini = 1, moninf = 1, monsup = 2)
dat <- 1 : (24 * 2 * 3)
dim(dat) <- c(dat = 2, time = 24, memb = 3)
res <- Season(data = dat, monini = 1, moninf = 1, monsup = 2)
dat[c(1, 20, 50)] <- NA
res1 <- Season(data = dat, monini = 1, moninf = 1, monsup = 2, na.rm = FALSE)
res2 <- Season(data = dat, monini = 1, moninf = 1, monsup = 2, na.rm = TRUE)
}

